package com.isu.gaswellwatch.modbus.data.decode.impl;

import com.isu.gaswellwatch.modbus.data.ModbusMessage;
import com.isu.gaswellwatch.modbus.data.decode.DecodeHandler;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.Map;

/**
 * 本地日期类型解析器
 *
 * @author <a href="mailto:shilong.wang@alpha-ess.com">王仕龙</a>
 * 2024/11/25 11:51
 */
@Slf4j
@SuppressWarnings("all")
@Component("localDateDecodeHandler")
public class LocalDateDecodeHandler implements DecodeHandler {
    public static final DateTimeFormatter IN_FORMATTER = DateTimeFormatter.ofPattern("yyyy-M-d");
    public static final DateTimeFormatter OUT_FORMATTER = DateTimeFormatter.ofPattern("yyyy-MM-dd");


    @Override
    public String decode(Map<String, Object> commandPointMap, String value) {
        return LocalDate.parse(value, IN_FORMATTER).format(OUT_FORMATTER);
    }

    @Override
    public void decode(Map<String, Object> commandPointMap, ModbusMessage.MessagePoint point) {
        point.setValue(decode(commandPointMap, point.getParseValue()));
    }

}
